@@ -1,12 +1,27 @@
 # $File: //member/autrijus/Class-PseudoHash/PseudoHash.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 1675 $ $DateTime: 2001/09/03 20:39:12 $
+# $Revision: #4 $ $Change: 2351 $ $DateTime: 2001/11/13 15:06:49 $
 
 package Class::PseudoHash;
-require 5.005;
+use 5.005;
 
-$Class::PseudoHash::VERSION = '0.02';
+$Class::PseudoHash::VERSION = '1.00';
 
 use strict;
+use vars qw/$FixedKeys $Obj $Proxy/;
+use constant NO_SUCH_FIELD => 'No such pseudohash field "%s"';
+use constant NO_SUCH_INDEX => 'Bad index while coercing array into hash';
+use overload (
+    '%{}'  => sub { $$Obj = $_[0]; return $Proxy },
+    '""'   => sub { overload::AddrRef($_[0]) },
+    '0+'   => sub { 
+	my $str = overload::AddrRef($_[0]);
+	hex(substr($str, index($str, '(') + 1, -1));
+    },
+    'bool' => sub { 1 },
+    'cmp'  => sub { "$_[0]" cmp "$_[1]" },
+    '<=>'  => sub { "$_[0]" cmp "$_[1]" }, # for completeness' sake
+    'fallback' => 1,
+);
 
 =head1 NAME
 
@@ -16,26 +31,26 @@ Class::PseudoHash - Emulates Pseudo-Hash behaviour via overload
 
     use Class::PseudoHash;
 
-    my @arg = ([qw/key1 key2 key3 key4/], [1..10]);
-    $ref = fields::phash(@arg);          # phash override
-    $ref = Class::PseudoHash->new(@arg); # constructor syntax
+    my @args = ([qw/key1 key2 key3 key4/], [1 .. 10]);
+    my $ref1 = fields::phash(@args);		# phash() override
+    my $ref2 = Class::PseudoHash->new(@args);	# constructor syntax
 
 =head1 DESCRIPTION
 
 Due to its impact on overall performance of ordinary hashes, pseudo-hashes
-are deprecated in perl v5.8, and will cease to exist in perl v5.10. The 
-C<fields> pragma is supposed to change to use a different implementation.
+are deprecated in perl v5.8, and will cease to exist in perl v5.10. By then,
+the C<fields> pragma is supposed to change to use a different implementation.
 
 Although L<perlref/Pseudo-hashes: Using an array as a hash> recommends
-against using the first-element-as-index behaviour, certainly there are
-many brave souls still writing such codes, and fear that the elimination
+against using the first-element-as-index behaviour, there are undoubtly
+many brave souls still writing such code, and fearing that the elimination
 of pseudo-hashes will require a massive rewrite of their programs.
 
-As one of the primary victims, I tried to find a drop-in solution that 
+As one of the primary victims, I tried to devise a drop-in solution that 
 could emulate exactly the same semantic of pseudo-hashes, thus keeping 
-all my legacy code intact. So C<Class::PseudoHash> is born.
+all my legacy code intact. So C<Class::PseudoHash> was born.
 
-Hence, if you're using the perferred C<fields::phash()> function, just 
+Hence, if you're using the preferred C<fields::phash()> function, just 
 write:
 
     use fields;
@@ -55,39 +70,19 @@ to access a non-existent hash key, then a new pseudo-hash entry will be
 created silently. This is most useful if you're already using untyped
 pseudo-hashes, and don't want the compile-time checking feature.
 
-=head1 CAVEATS
-
-Compile-type validating of keys is not possible with this module,
-for obvious reasons. Also, the performance will not be as fast as
-typed pseudo-hashes (but generally faster than untyped ones).
-
-The numeric context overloading (C<0+>) is broken, and i don't have the
-time to track it down.
+Compile-time validating of keys is not possible with this module, for
+obvious reasons. Also, the performance will not be as fast as typed
+pseudo-hashes (but generally faster than untyped ones).
 
 =cut
 
-use constant NO_SUCH_FIELD => 'No such pseudohash field "%s"';
-use constant NO_SUCH_INDEX => 'Bad index while coercing array into hash';
-
-use vars qw/$FixedKeys/;
 $FixedKeys = 1;
 
-my ($obj, $proxy);
-
-use overload (
-    '%{}'  => sub { $$obj = $_[0]; return $proxy },
-    '""'   => sub { overload::AddrRef($_[0]) },
-    '0+'   => sub { 0 },
-    'bool' => sub { 1 },
-    'cmp'  => sub { "$_[0]" cmp "$_[1]" },
-    '<=>'  => sub { "$_[0]" cmp "$_[1]" }, # for completeness' sake
-);
-
 sub import {
     no strict 'refs';
 
     my $class = shift;
-    tie %{$proxy}, $class;
+    tie %{$Proxy}, $class;
 
     *{'fields::phash'} = sub {
 	$class->new(@_);
@@ -114,31 +109,33 @@ sub new {
 
 sub FETCH {
     my ($self, $key) = @_;
+
     $self = $$$self;
 
     return $self->[
-	$self->[0]{$key} >= 1 
-	    ? $self->[0]{$key}
-	    : defined($self->[0]{$key})
-                ? _croak(NO_SUCH_INDEX)
-	        : $FixedKeys 
-		    ? _croak(NO_SUCH_FIELD, $key)
-		    : @$self
+	$self->[0]{$key} >= 1
+	    ? $self->[0]{$key} :
+	defined($self->[0]{$key})
+	    ? _croak(NO_SUCH_INDEX) :
+	$FixedKeys
+	    ? _croak(NO_SUCH_FIELD, $key) :
+	@$self
     ];
 }
 
 sub STORE {
     my ($self, $key, $value) = @_;
+
     $self = $$$self;
 
     return $self->[
-	$self->[0]{$key} >= 1 
-	    ? $self->[0]{$key}
-	    : defined($self->[0]{$key})
-                ? _croak(NO_SUCH_INDEX)
-	        : $FixedKeys 
-		    ? _croak(NO_SUCH_FIELD, $key)
-		    : @$self
+	$self->[0]{$key} >= 1
+	    ? $self->[0]{$key} :
+	defined($self->[0]{$key})
+	    ? _croak(NO_SUCH_INDEX) :
+	$FixedKeys
+	    ? _croak(NO_SUCH_FIELD, $key) :
+	@$self
     ] = $value;
 }
 
@@ -148,7 +145,7 @@ sub _croak {
 }
 
 sub TIEHASH {
-    bless \$obj => shift;
+    bless \$Obj => shift;
 }
 
 sub FIRSTKEY {
@@ -169,7 +166,7 @@ sub DELETE {
 }
 
 sub CLEAR {
-    @{$${$_[0]}} = undef;
+    @{$${$_[0]}} = ();
 }
 
 1;
@@ -181,11 +178,11 @@ L<perlref/Pseudo-hashes: Using an array as a hash>
 
 =head1 AUTHORS
 
-Autrijus Tang E<lt>autrijus@autrijus.org>
+Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 by Autrijus Tang E<lt>autrijus@autrijus.org>.
+Copyright 2001 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
